# amc13.py - support module for AMC13 access via ipbus
# This module manages a connection to an AMC13 using
# the serial-number based IP address scheme
#
# sn = sn1()
#    determine serial number from environment, or ask user
#    returns serial number
#
# (t1, t2) = connect(serial_no)
#    Establish a connection to module based on serial number
#    returns PyChips ChipsBusUdp objects for T1, T2 boards
#
# (ip1, ip2) = ip_addr(serial_no)
#    calculate IP addresses from serial number and return them
#

import os
from PyChipsUser import *

def sn1():
	if "AMC13_SERIAL_NO" in os.environ:
		serial_no = os.environ["AMC13_SERIAL_NO"]
		print "AMC13 Serial Number ", serial_no
	else:
		while True:
			print "Enter AMC13 Serial Number"
			x = raw_input('>> ')
			y = AddressTable("../addresstables_amc13/AMC13_AddressTable_V6_v01.txt")
			ip = "192.168.1." + str(255 - 2*int(x))
			z = ChipsBusUdp(y, ip, 50001)
			try:
				id = z.read("ID", 0)
				print "id = ", id
				serial_no = x
				print "Please set environment variable AMC13_SERIAL_NO:"
				print "Add \"export AMC13_SERIAL_NO=n\" to your .bashrc file -or-"
				print "Add \"setenv AMC13_SERIAL_NO n\" to your .tcshrc file"
				break
			except ChipsException:
				print "No AMC13 found with this Serial Number"
				True
	return serial_no

def sn_safe():
	while True:
		print "Enter AMC13 Serial Number"
		x = raw_input('>> ')
		y = AddressTable("../addresstables_amc13/AMC13_AddressTable_V6_v01.txt")
		ip = "192.168.1." + str(255 - 2*int(x))
		z = ChipsBusUdp(y, ip, 50001)
		try:
			id = z.read("ID", 0)
			print "id = ", id
			serial_no = x
			break
		except ChipsException:
			print "No AMC13 found with this Serial Number"
			True
	return serial_no

def connect(serial_no):
	global t1_address_table
	t1_address_table = AddressTable("../addresstables_amc13/AMC13_AddressTable_V6_v01.txt")
	global t1_ip_address
	t1_ip_address = '192.168.1.' + str(255 - 2*int(serial_no))
	global t2_address_table
	t2_address_table = AddressTable("../addresstables_amc13/AMC13_AddressTable_S6_v01.txt")
	global t2_ip_address
	t2_ip_address = '192.168.1.' + str(254 - 2*int(serial_no))
	 
	global t1
	t1 = ChipsBusUdp(t1_address_table, t1_ip_address, 50001)
	global t2
	t2 = ChipsBusUdp(t2_address_table, t2_ip_address, 50001)

	return (t1, t2) 

def ip_addr(serial_no):
	ip1 = str(255 - 2*int(serial_no))
	ip2 = str(254 - 2*int(serial_no))
	return ip1, ip2
